library(ggplot2)
library(RColorBrewer)

dom="D2" ; k = 5
calendario <- seq(as.Date("1950-01-01"),as.Date("2020-12-31"),by="day")

setwd("Documents/")
load(file = paste("WardCluster_Dendrogram_",dom,"_50km.Rdata",sep=""))
vector_cluster <- cutree(ward_clustering,k)[which(format(calendario,"%Y")%in%c(1950:2021))]

vector_cluster0 <- vector_cluster[1:length(vector_cluster)-1]
vector_cluster2 <- vector_cluster[2:length(vector_cluster)]

df <- data.frame(from=vector_cluster0,to=vector_cluster2)
df$count <- 1

df <- aggregate(count~from+to, data=df, sum)
nodes <- unique(c(df$from,df$to))
df1 <- merge(expand.grid(from=nodes, to=nodes), df, by=c('from','to'), all=TRUE)
df1$count[is.na(df1$count)] <- 0
dffinal <- df1

##################################################################################
#Significance with bootstrapping
trials = 1000
vc <- list()
for(t in 1:trials){
  if(t ==1){
  vc[[t]] <- sample(x=vector_cluster,size = length(vector_cluster))
  
  vc0 <- vc[[t]][1:length(vc[[t]])-1]
  vc2 <- vc[[t]][2:length(vc[[t]])]
  df <- data.frame(from=vc0,to=vc2)
  df$count <- 1
  
  df <- aggregate(count~from+to, data=df, sum)
  nodes <- unique(c(df$from,df$to))
  df2 <- merge(expand.grid(from=nodes, to=nodes), df, by=c('from','to'), all=TRUE)
  df2$count[is.na(df2$count)] <- 0
  df2$trial <- rep(t,dim(df2)[1])
  
  datos = df2
  }else{
    vc[[t]] <- sample(x=vector_cluster,size = length(vector_cluster))
    
    vc0 <- vc[[t]][1:length(vc[[t]])-1]
    vc2 <- vc[[t]][2:length(vc[[t]])]
    df <- data.frame(from=vc0,to=vc2)
    df$count <- 1
    
    df <- aggregate(count~from+to, data=df, sum)
    nodes <- unique(c(df$from,df$to))
    df1 <- merge(expand.grid(from=nodes, to=nodes), df, by=c('from','to'), all=TRUE)
    df1$count[is.na(df1$count)] <- 0
    df1$trial <- rep(t,dim(df1)[1])
    
    datos <- rbind(datos,df1)
  }
}

quant9 <- function(x){
  quantile(x,probs=0.9,na.rm=T)
}

quant1 <- function(x){
  quantile(x,probs=0.1,na.rm=T)
}

q95 <- aggregate(data=datos,count~from+to,FUN = quant9)
q05 <- aggregate(data=datos,count~from+to,FUN = quant1)

dffinal$sign <- 0
dffinal$sign[which(dffinal$count>q95$count)] <- 1

signif <- subset(dffinal,sign>0)
signif$sign[which(signif$from==2 & signif$to==5)]
p <- ggplot(data=dffinal,aes(x=to,y=from,fill=count/length(vector_cluster)*100)) + geom_tile() + 
  scale_fill_gradientn(name="%",colors=brewer.pal(8,"Paired"),limits=c(0,32),breaks=seq(0,32,by=8)) + theme_bw() +
  geom_text(label=round(dffinal$count/length(vector_cluster)*100,digits=1)) +
  #geom_text(data=signif,aes(x=to,y=from),label=round(signif$count/length(vector_cluster)*100,digits=1),fontface="bold")
  #geom_text(label=round(dffinal$count[which(dffinal$sign==1)]/length(vector_cluster)*100,digits=1),fontface="bold")
ggsave(p,filename=paste("TransitionsAndPersistence_",dom,"_",k,"CPs.png",sep=""),device="png",
       dpi=600,width=3,height = 3)


#################################################################################
dom="D2" ; k = 7
calendario <- seq(as.Date("1950-01-01"),as.Date("2020-12-31"),by="day")

setwd("Documents/")
load(file = paste("WardCluster_Dendrogram_",dom,"_50km.Rdata",sep=""))
vector_cluster <- cutree(ward_clustering,k)[which(format(calendario,"%Y")%in%c(1950:2021))]

vector_cluster0 <- vector_cluster[1:length(vector_cluster)-1]
vector_cluster2 <- vector_cluster[2:length(vector_cluster)]

df <- data.frame(from=vector_cluster0,to=vector_cluster2)
df$count <- 1

df <- aggregate(count~from+to, data=df, sum)
nodes <- unique(c(df$from,df$to))
df1 <- merge(expand.grid(from=nodes, to=nodes), df, by=c('from','to'), all=TRUE)
df1$count[is.na(df1$count)] <- 0
dffinal <- df1

##################################################################################
#Significance with bootstrapping
trials = 1000
vc <- list()
for(t in 1:trials){
  if(t ==1){
    vc[[t]] <- sample(x=vector_cluster,size = length(vector_cluster))
    
    vc0 <- vc[[t]][1:length(vc[[t]])-1]
    vc2 <- vc[[t]][2:length(vc[[t]])]
    df <- data.frame(from=vc0,to=vc2)
    df$count <- 1
    
    df <- aggregate(count~from+to, data=df, sum)
    nodes <- unique(c(df$from,df$to))
    df1 <- merge(expand.grid(from=nodes, to=nodes), df, by=c('from','to'), all=TRUE)
    df2$count[is.na(df2$count)] <- 0
    df2$trial <- rep(t,dim(df2)[1])
    
    datos = df2
  }else{
    vc[[t]] <- sample(x=vector_cluster,size = length(vector_cluster))
    
    vc0 <- vc[[t]][1:length(vc[[t]])-1]
    vc2 <- vc[[t]][2:length(vc[[t]])]
    df <- data.frame(from=vc0,to=vc2)
    df$count <- 1
    
    df <- aggregate(count~from+to, data=df, sum)
    nodes <- unique(c(df$from,df$to))
    df1 <- merge(expand.grid(from=nodes, to=nodes), df, by=c('from','to'), all=TRUE)
    df1$count[is.na(df1$count)] <- 0
    df1$trial <- rep(t,dim(df1)[1])
    
    datos <- rbind(datos,df1)
  }
}

quant9 <- function(x){
  quantile(x,probs=0.9,na.rm=T)
}

quant1 <- function(x){
  quantile(x,probs=0.1,na.rm=T)
}

q95 <- aggregate(data=datos,count~from+to,FUN = quant9)
q05 <- aggregate(data=datos,count~from+to,FUN = quant1)

dffinal$sign <- 0
dffinal$sign[which(dffinal$count>q95$count)] <- 1

signif <- subset(dffinal,sign>0)
p <- ggplot(data=dffinal,aes(x=to,y=from,fill=count/length(vector_cluster)*100)) + geom_tile() + 
  scale_fill_gradientn(name="%",colors=brewer.pal(8,"Paired"),limits=c(0,32),breaks=seq(0,32,by=8)) + theme_bw() +
  geom_text(label=round(dffinal$count/length(vector_cluster)*100,digits=1)) #+
#geom_text(data=signif,aes(x=to,y=from),label=round(signif$count/length(vector_cluster)*100,digits=1),fontface="bold")
#geom_text(label=round(dffinal$count[which(dffinal$sign==1)]/length(vector_cluster)*100,digits=1),fontface="bold")
ggsave(p,filename=paste("TransitionsAndPersistence_",dom,"_",k,"CPs.png",sep=""),device="png",
       dpi=600,width=3,height = 3)
